import React from 'react';

interface StatCardProps {
  title: string;
  value: string;
  description: string;
}

const StatCard: React.FC<StatCardProps> = ({ title, value, description }) => {
  return (
    <div className="bg-gray-800/50 backdrop-blur-md p-6 rounded-lg shadow-xl hover:shadow-indigo-500/30 transform hover:-translate-y-1 transition-all duration-300">
      <h3 className="text-indigo-400 text-xl font-semibold mb-2">{title}</h3>
      <p className="text-4xl font-bold text-white mb-3">{value}</p>
      <p className="text-gray-400 text-sm">{description}</p>
    </div>
  );
};

const StatisticsSection: React.FC = () => {
  const stats = [
    {
      title: "Total de Candidatos",
      value: "+500.000",
      description: "Registros de candidaturas desde 2014"
    },
    {
      title: "Total de Bens Declarados",
      value: "R$ +1 Trilhão",
      description: "Patrimônio agregado declarado pelos candidatos"
    },
    {
      title: "Anos de Eleição Processados",
      value: "2014 - 2024",
      description: "Cobertura das últimas eleições gerais e municipais"
    }
  ];

  return (
    <section id="stats" className="py-20 bg-gray-900">
      <div className="container mx-auto px-4">
        <h2 className="text-3xl font-bold text-center text-white mb-12">
          Dados em Números
        </h2>
        <div className="grid md:grid-cols-3 gap-8">
          {stats.map((stat, index) => (
            <StatCard key={index} title={stat.title} value={stat.value} description={stat.description} />
          ))}
        </div>
      </div>
    </section>
  );
};

export default StatisticsSection;
